/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.logging.ri.commons;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jdtaus.core.container.ContainerInitializer;
import org.jdtaus.core.container.Dependency;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Properties;
import org.jdtaus.core.container.Property;
import org.jdtaus.core.container.PropertyException;
import org.jdtaus.core.logging.spi.Logger;

/**
 * jDTAUS Core SPI Commons Logging {@code Logger} implementation.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: CommonsLoggingLogger.java 3210 2007-04-29 21:36:10Z schulte2005 $
 */
public final class CommonsLoggingLogger implements ContainerInitializer, Logger
{

    //--Implementation----------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(CommonsLoggingLogger.class.getName());

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /**
     * Protected <code>CommonsLoggingLogger</code> implementation constructor.
     *
     * @param meta Implementation meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    protected CommonsLoggingLogger(final Implementation meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }
    /**
     * Protected <code>CommonsLoggingLogger</code> dependency constructor.
     *
     * @param meta dependency meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    protected CommonsLoggingLogger(final Dependency meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }

    /**
     * Initializes the properties of the instance.
     *
     * @param meta the property values to initialize the instance with.
     *
     * @throws NullPointerException if {@code meta} is {@code null}.
     */
    protected void initializeProperties(final Properties meta)
    {
        Property p;

        if(meta == null)
        {
            throw new NullPointerException("meta");
        }

        p = meta.getProperty("name");
        this._name = (java.lang.String) p.getValue();

    }

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------

    /** Commons logging logger. */
    private Log logger;

    public void initialize()
    {
        this.assertValidProperties();
        this.logger = LogFactory.getLog(this.getName());
    }

    //----------------------------------------------------ContainerInitializer--
    //--Properties--------------------------------------------------------------

    // This section is managed by jdtaus-container-mojo.

    /**
     * Property {@code name}.
     * @serial
     */
    private java.lang.String _name;

    /**
     * Gets the value of property <code>name</code>.
     *
     * @return the value of property <code>name</code>.
     */
    protected java.lang.String getName()
    {
        return this._name;
    }


    //--------------------------------------------------------------Properties--
    //--Logger------------------------------------------------------------------

    public boolean isDebugEnabled()
    {
        return this.logger.isDebugEnabled();
    }

    public void debug(String message)
    {
        this.logger.debug(message);
    }

    public void debug(Throwable throwable)
    {
        this.logger.debug(throwable.getMessage(), throwable);
    }

    public boolean isErrorEnabled()
    {
        return this.logger.isErrorEnabled();
    }

    public void error(String message)
    {
        this.logger.error(message);
    }

    public void error(Throwable throwable)
    {
        this.logger.error(throwable.getMessage(), throwable);
    }

    public boolean isFatalEnabled()
    {
        return this.logger.isFatalEnabled();
    }

    public void fatal(String message)
    {
        this.logger.fatal(message);
    }

    public void fatal(Throwable throwable)
    {
        this.logger.fatal(throwable.getMessage(), throwable);
    }

    public boolean isInfoEnabled()
    {
        return this.logger.isInfoEnabled();
    }

    public void info(String message)
    {
        this.logger.info(message);
    }

    public void info(Throwable throwable)
    {
        this.logger.info(throwable.getMessage(), throwable);
    }

    public boolean isTraceEnabled()
    {
        return this.logger.isTraceEnabled();
    }

    public void trace(String message)
    {
        this.logger.trace(message);
    }

    public void trace(Throwable throwable)
    {
        this.logger.trace(throwable.getMessage(), throwable);
    }

    public boolean isWarnEnabled()
    {
        return this.logger.isWarnEnabled();
    }

    public void warn(String message)
    {
        this.logger.warn(message);
    }

    public void warn(Throwable throwable)
    {
        this.logger.warn(throwable.getMessage(), throwable);
    }

    //------------------------------------------------------------------Logger--
    //--CommonsLoggingLogger----------------------------------------------------

    /** Creates a new {@code CommonsLoggingLogger} instance. */
    public CommonsLoggingLogger()
    {
        this(CommonsLoggingLogger.META);
        this.initialize();
    }

    /**
     * Checks configured properties.
     *
     * @throws PropertyException if property {@code name} is {@code null} or
     * of no length.
     */
    protected void assertValidProperties()
    {
        if(this.getName() == null || this.getName().length() <= 0)
        {
            throw new PropertyException("name", this.getName());
        }
    }

    //----------------------------------------------------CommonsLoggingLogger--

}
